@@ -1,8 +1,4 @@
-#!/usr/bin/env python
-
-"""
-Integration tests for the doorstop.cli package.
-"""
+"""Integration tests for the doorstop.cli package."""
 
 import unittest
 from unittest.mock import patch, Mock
@@ -13,21 +9,29 @@ import shutil
 
 from doorstop.cli.main import main
 from doorstop import common
+from doorstop import settings
 
 from doorstop.cli.test import ENV, REASON, TUTORIAL
 
 
 @unittest.skipUnless(os.getenv(ENV), REASON)  # pylint: disable=R0904
 class TestMain(unittest.TestCase):  # pylint: disable=R0904
+
     """Integration tests for the 'doorstop' command."""
 
     def setUp(self):
         self.cwd = os.getcwd()
         self.temp = tempfile.mkdtemp()
+        self.backup = (settings.REFORMAT,
+                       settings.CHECK_REF,
+                       settings.CHECK_RLINKS)
 
     def tearDown(self):
         os.chdir(self.cwd)
         shutil.rmtree(self.temp)
+        (settings.REFORMAT,
+         settings.CHECK_REF,
+         settings.CHECK_RLINKS) = self.backup
 
     def test_main(self):
         """Verify 'doorstop' can be called."""
@@ -42,6 +46,11 @@ class TestMain(unittest.TestCase):  # pylint: disable=R0904
         os.chdir(self.temp)
         self.assertRaises(SystemExit, main, [])
 
+    def test_main_custom_root(self):
+        """Verify 'doorstop' can be provided a custom root path."""
+        os.chdir(self.temp)
+        self.assertIs(None, main(['--project', '.']))
+
     @patch('doorstop.cli.main._run', Mock(return_value=False))
     def test_exit(self):
         """Verify 'doorstop' treats False as an error ."""
@@ -57,6 +66,20 @@ class TestMain(unittest.TestCase):  # pylint: disable=R0904
         os.mkdir(os.path.join(self.temp, '.mockvcs'))
         os.chdir(self.temp)
         self.assertIs(None, main([]))
+        self.assertTrue(settings.REFORMAT)
+        self.assertTrue(settings.CHECK_REF)
+        self.assertTrue(settings.CHECK_RLINKS)
+
+    def test_options(self):
+        """Verify 'doorstop' can be run with options."""
+        os.mkdir(os.path.join(self.temp, '.mockvcs'))
+        os.chdir(self.temp)
+        self.assertIs(None, main(['--no-reformat',
+                                  '--no-ref-check',
+                                  '--no-rlinks-check']))
+        self.assertFalse(settings.REFORMAT)
+        self.assertFalse(settings.CHECK_REF)
+        self.assertFalse(settings.CHECK_RLINKS)
 
     @patch('doorstop.cli.main.gui', Mock(return_value=True))
     def test_gui(self):
@@ -66,6 +89,7 @@ class TestMain(unittest.TestCase):  # pylint: disable=R0904
 
 @unittest.skipUnless(os.getenv(ENV), REASON)  # pylint: disable=R0904
 class TestNew(unittest.TestCase):  # pylint: disable=R0904
+
     """Integration tests for the 'doorstop new' command."""
 
     def setUp(self):
@@ -89,6 +113,7 @@ class TestNew(unittest.TestCase):  # pylint: disable=R0904
 
 @unittest.skipUnless(os.getenv(ENV), REASON)  # pylint: disable=R0904
 class TestAdd(unittest.TestCase):  # pylint: disable=R0904
+
     """Integration tests for the 'doorstop add' command."""
 
     @classmethod
@@ -114,16 +139,17 @@ class TestAdd(unittest.TestCase):  # pylint: disable=R0904
 
 @unittest.skipUnless(os.getenv(ENV), REASON)  # pylint: disable=R0904
 class TestRemove(unittest.TestCase):  # pylint: disable=R0904
+
     """Integration tests for the 'doorstop remove' command."""
 
     ITEM = os.path.join(TUTORIAL, 'TUT003.yml')
 
     def setUp(self):
-        with open(self.ITEM, 'rb') as item:
+        with open(self.ITEM, 'r') as item:
             self.backup = item.read()
 
     def tearDown(self):
-        with open(self.ITEM, 'wb') as item:
+        with open(self.ITEM, 'w') as item:
             item.write(self.backup)
 
     def test_remove(self):
@@ -132,22 +158,23 @@ class TestRemove(unittest.TestCase):  # pylint: disable=R0904
         self.assertFalse(os.path.exists(self.ITEM))
 
     def test_remove_error(self):
-        """Verify 'doorstop remove' returns an error on unknown items."""
+        """Verify 'doorstop remove' returns an error on unknown item IDs."""
         self.assertRaises(SystemExit, main, ['remove', 'tut9999'])
 
 
 @unittest.skipUnless(os.getenv(ENV), REASON)  # pylint: disable=R0904
 class TestLink(unittest.TestCase):  # pylint: disable=R0904
+
     """Integration tests for the 'doorstop link' command."""
 
     ITEM = os.path.join(TUTORIAL, 'TUT003.yml')
 
     def setUp(self):
-        with open(self.ITEM, 'rb') as item:
+        with open(self.ITEM, 'r') as item:
             self.backup = item.read()
 
     def tearDown(self):
-        with open(self.ITEM, 'wb') as item:
+        with open(self.ITEM, 'w') as item:
             item.write(self.backup)
 
     def test_link(self):
@@ -167,17 +194,18 @@ class TestLink(unittest.TestCase):  # pylint: disable=R0904
 
 @unittest.skipUnless(os.getenv(ENV), REASON)  # pylint: disable=R0904
 class TestUnlink(unittest.TestCase):  # pylint: disable=R0904
+
     """Integration tests for the 'doorstop unlink' command."""
 
     ITEM = os.path.join(TUTORIAL, 'TUT003.yml')
 
     def setUp(self):
-        with open(self.ITEM, 'rb') as item:
+        with open(self.ITEM, 'r') as item:
             self.backup = item.read()
         main(['link', 'tut3', 'req2'])  # create a temporary link
 
     def tearDown(self):
-        with open(self.ITEM, 'wb') as item:
+        with open(self.ITEM, 'w') as item:
             item.write(self.backup)
 
     def test_unlink(self):
@@ -197,6 +225,7 @@ class TestUnlink(unittest.TestCase):  # pylint: disable=R0904
 
 @unittest.skipUnless(os.getenv(ENV), REASON)  # pylint: disable=R0904
 class TestEdit(unittest.TestCase):  # pylint: disable=R0904
+
     """Integration tests for the 'doorstop edit' command."""
 
     @patch('doorstop.core.tree._open')
@@ -211,26 +240,9 @@ class TestEdit(unittest.TestCase):  # pylint: disable=R0904
         self.assertRaises(SystemExit, main, ['edit', 'req9999'])
 
 
-@unittest.skipUnless(os.getenv(ENV), REASON)  # pylint: disable=R0904
-class TestImport(unittest.TestCase):  # pylint: disable=R0904
-    """Integration tests for the 'doorstop import' command."""
-
-    def test_import(self):  # TODO: implement test: doorstop import
-        """Verify 'doorstop import' can be called."""
-        self.assertRaises(NotImplementedError, main, ['import', 'PATH'])
-
-
-@unittest.skipUnless(os.getenv(ENV), REASON)  # pylint: disable=R0904
-class TestExport(unittest.TestCase):  # pylint: disable=R0904
-    """Integration tests for the 'doorstop export' command."""
-
-    def test_export(self):  # TODO: implement test: doorstop export
-        """Verify 'doorstop export' can be called."""
-        self.assertRaises(NotImplementedError, main, ['export', 'PATH'])
-
-
 @unittest.skipUnless(os.getenv(ENV), REASON)  # pylint: disable=R0904
 class TestPublish(unittest.TestCase):  # pylint: disable=R0904
+
     """Integration tests for the 'doorstop publish' command."""
 
     def setUp(self):
@@ -241,6 +253,11 @@ class TestPublish(unittest.TestCase):  # pylint: disable=R0904
         os.chdir(self.cwd)
         shutil.rmtree(self.temp)
 
+    def test_publish_error(self):
+        """Verify 'doorstop publish' returns an error in an empty folder."""
+        os.chdir(self.temp)
+        self.assertRaises(SystemExit, main, ['publish', 'req'])
+
     def test_publish_text(self):
         """Verify 'doorstop publish' can create text output."""
         self.assertIs(None, main(['publish', 'tut', '--width', '75']))
@@ -271,14 +288,28 @@ class TestPublish(unittest.TestCase):  # pylint: disable=R0904
         self.assertIs(None, main(['publish', 'req', path]))
         self.assertTrue(os.path.isfile(path))
 
-    def test_report_error(self):
-        """Verify 'doorstop publish' returns an error in an empty folder."""
-        os.chdir(self.temp)
-        self.assertRaises(SystemExit, main, ['publish', 'req'])
+    def test_publish_tree_html(self):
+        """Verify 'doorstop publish' can create an HTML directory."""
+        path = os.path.join(self.temp, 'all')
+        self.assertIs(None, main(['publish', 'all', path]))
+        self.assertTrue(os.path.isdir(path))
+        self.assertTrue(os.path.isfile(os.path.join(path, 'index.html')))
+
+    def test_publish_tree_text(self):
+        """Verify 'doorstop publish' can create a text directory."""
+        path = os.path.join(self.temp, 'all')
+        self.assertIs(None, main(['publish', 'all', path, '--text']))
+        self.assertTrue(os.path.isdir(path))
+        self.assertFalse(os.path.isfile(os.path.join(path, 'index.html')))
+
+    def test_publish_tree_no_path(self):
+        """Verify 'doorstop publish' returns an error with no path."""
+        self.assertRaises(SystemExit, main, ['publish', 'all'])
 
 
 @patch('doorstop.cli.main._run', Mock(return_value=True))  # pylint: disable=R0904
 class TestLogging(unittest.TestCase):  # pylint: disable=R0904
+
     """Integration tests for the Doorstop CLI logging."""
 
     def test_verbose_1(self):
